LIANA: a LIgand-receptor ANalysis frAmework
===========================================

|MainBuild| |Issues| |Docs| |Codecov|

.. |MainBuild| image:: https://github.com/saezlab/liana-py/actions/workflows/main.yml/badge.svg
   :target: https://github.com/saezlab/liana-py/actions
   
.. |Issues| image:: https://img.shields.io/github/issues/saezlab/liana-py.svg
   :target: https://github.com/saezlab/liana-py/issues/
   
.. |Docs| image:: https://readthedocs.org/projects/liana-py/badge/?version=latest
   :target: https://readthedocs.org/projects/liana-py/badge/?version=latest

.. |Codecov| image:: https://codecov.io/gh/saezlab/liana-py/branch/main/graph/badge.svg?token=TM0P29KKN5
   :target: https://codecov.io/gh/saezlab/liana-py


This is its faster and memory efficient Python implementation, an R version is also available `here <https://saezlab.github.io/liana/>`_.

Check out the `Usage <https://liana-py.readthedocs.io/en/latest/notebooks/basic_usage.html>`_ or any other tutorial for further information.


Cite LIANA
----------
Dimitrov, D., Türei, D., Garrido-Rodriguez M., Burmedi P.L., Nagai, J.S., Boys, C., Flores, R.O.R., Kim, H., Szalai, B., Costa, I.G., Valdeolivas, A., Dugourd, A. and Saez-Rodriguez, J. Comparison of methods and resources for cell-cell communication inference from single-cell RNA-Seq data. Nat Commun 13, 3224 (2022). https://doi.org/10.1038/s41467-022-30755-0

Also, if you use the OmniPath CCC Resource for your analysis, please cite:
Türei, D., Valdeolivas, A., Gul, L., Palacio‐Escat, N., Klein, M., Ivanova, O., Ölbei, M., Gábor, A., Theis, F., Módos, D. and Korcsmáros, T., 2021. Integrated intra‐and intercellular signaling knowledge for multicellular omics analysis. Molecular systems biology, 17(3), p.e9923. https://doi.org/10.15252/msb.20209923


.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Main

   installation
   api
   release_notes
   reference

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Vignettes

   notebooks/basic_usage

   notebooks/liana_c2c

   notebooks/mofacell

   notebooks/mofatalk
